import json
import time
from urllib.request import urlopen


def parse_fissure(type, data, data2="N/A"):
    if isinstance(fissure_parser[type][data], str) or isinstance(fissure_parser[type][data], int):
        return fissure_parser[type][data]
    else:
        return fissure_parser[type][data][data2]


fissure_parser = {
    "location": {
        "SolNode0": "SolNode0",
        "SolNode1": "Galatea",
        "SolNode2": "Aphrodite",
        "SolNode3": "Cordelia",
        "SolNode4": "Acheron",
        "SolNode5": "Perdita",
        "SolNode6": "Despina",
        "SolNode7": "Epimetheus",
        "SolNode8": "Nix",
        "SolNode9": "Rosalind",
        "SolNode10": "Thebe",
        "SolNode11": "Tharsis",
        "SolNode12": "Elion",
        "SolNode13": "Bianca",
        "SolNode14": "Ultor",
        "SolNode15": "Pacific",
        "SolNode16": "Augustus",
        "SolNode17": "Proteus",
        "SolNode18": "Rhea",
        "SolNode19": "Enceladus",
        "SolNode20": "Telesto",
        "SolNode21": "Narcissus",
        "SolNode22": "Tessera",
        "SolNode23": "Cytherean",
        "SolNode24": "Oro",
        "SolNode25": "Callisto",
        "SolNode26": "Lith",
        "SolNode27": "E Prime",
        "SolNode28": "M Prime",
        "SolNode29": "Oberon",
        "SolNode30": "Olympus",
        "SolNode31": "Anthe",
        "SolNode32": "Tethys",
        "SolNode33": "Ariel",
        "SolNode34": "Sycorax",
        "SolNode35": "Arcadia",
        "SolNode36": "Martialis",
        "SolNode37": "Pallene",
        "SolNode38": "Minthe",
        "SolNode39": "Everest",
        "SolNode40": "Prospero",
        "SolNode41": "Arval",
        "SolNode42": "Helene",
        "SolNode43": "Cerberus",
        "SolNode44": "Mimas",
        "SolNode45": "Ara",
        "SolNode46": "Spear",
        "SolNode47": "Janus",
        "SolNode48": "Regna",
        "SolNode49": "Larissa",
        "SolNode50": "Numa",
        "SolNode51": "Hades",
        "SolNode52": "Portia",
        "SolNode53": "Themisto",
        "SolNode54": "Silvanus",
        "SolNode55": "Methone",
        "SolNode56": "Cypress",
        "SolNode57": "Sao",
        "SolNode58": "Hellas",
        "SolNode59": "Eurasia",
        "SolNode60": "Caliban",
        "SolNode61": "Ishtar",
        "SolNode62": "Neso",
        "SolNode63": "Mantle",
        "SolNode64": "Umbriel",
        "SolNode65": "Gradivus",
        "SolNode66": "Unda",
        "SolNode67": "Dione",
        "SolNode68": "Vallis",
        "SolNode69": "Ophelia",
        "SolNode70": "Cassini",
        "SolNode71": "Vesper",
        "SolNode72": "Outer Terminus",
        "SolNode73": "Ananke",
        "SolNode74": "Carme",
        "SolNode75": "Cervantes",
        "SolNode76": "Hydra",
        "SolNode77": "Cupid",
        "SolNode78": "Triton",
        "SolNode79": "Cambria",
        "SolNode80": "Phoebe",
        "SolNode81": "Palus",
        "SolNode82": "Calypso",
        "SolNode83": "Cressida",
        "SolNode84": "Nereid",
        "SolNode85": "Gaia",
        "SolNode86": "Aegaeon",
        "SolNode87": "Ganymede",
        "SolNode88": "Adrastea",
        "SolNode89": "Mariana",
        "SolNode90": "Miranda",
        "SolNode91": "Iapetus",
        "SolNode92": "Charon",
        "SolNode93": "Keeler",
        "SolNode94": "Apollodorus",
        "SolNode95": "Thalassa",
        "SolNode96": "Titan",
        "SolNode97": "Amalthea",
        "SolNode98": "Desdemona",
        "SolNode99": "War",
        "SolNode100": "Elara",
        "SolNode101": "Kiliken",
        "SolNode102": "Oceanum",
        "SolNode103": "Terminus",
        "SolNode104": "Fossa",
        "SolNode105": "Titania",
        "SolNode106": "Alator",
        "SolNode107": "Venera",
        "SolNode108": "Tolstoj",
        "SolNode109": "Linea",
        "SolNode110": "Hyperion",
        "SolNode111": "Juliet",
        "SolNode112": "Setebos",
        "SolNode113": "Ares",
        "SolNode114": "Puck",
        "SolNode115": "Quirinus",
        "SolNode116": "Mab",
        "SolNode117": "Naiad",
        "SolNode118": "Laomedeia",
        "SolNode119": "Caloris",
        "SolNode120": "Halimede",
        "SolNode121": "Carpo",
        "SolNode122": "Stephano",
        "SolNode123": "V Prime",
        "SolNode124": "Trinculo",
        "SolNode125": "Io",
        "SolNode126": "Metis",
        "SolNode127": "Psamathe",
        "SolNode128": "E Gate",
        "SolNode129": "Orb Vallis",
        "SolNode130": "Lares",
        "SolNode131": "Pallas",
        "SolNode132": "Bode",
        "SolNode133": "Vedic",
        "SolNode134": "Varro",
        "SolNode135": "Thon",
        "SolNode136": "Olla",
        "SolNode137": "Nuovo",
        "SolNode138": "Ludi",
        "SolNode139": "Lex",
        "SolNode140": "Kiste",
        "SolNode141": "Ker",
        "SolNode142": "Hapke",
        "SolNode143": "Gefion",
        "SolNode144": "Exta",
        "SolNode145": "Egeria",
        "SolNode146": "Draco",
        "SolNode147": "Cinxia",
        "SolNode148": "Cerium",
        "SolNode149": "Casta",
        "SolNode150": "Albedo",
        "SolNode151": "Acanth",
        "SolNode152": "Ascar",
        "SolNode153": "Brugia",
        "SolNode154": "Candiru",
        "SolNode155": "Cosis",
        "SolNode156": "Cyath",
        "SolNode157": "Giardia",
        "SolNode158": "Gnathos",
        "SolNode159": "Lepis",
        "SolNode160": "Histo",
        "SolNode161": "Hymeno",
        "SolNode162": "Isos",
        "SolNode163": "Ixodes",
        "SolNode164": "Kala-azar",
        "SolNode165": "Sporid",
        "SolNode166": "Nimus",
        "SolNode167": "Oestrus",
        "SolNode168": "Phalan",
        "SolNode169": "Psoro",
        "SolNode170": "Ranova",
        "SolNode171": "Saxis",
        "SolNode172": "Xini",
        "SolNode173": "Solium",
        "SolNode174": "Sparga",
        "SolNode175": "Naeglar",
        "SolNode176": "Viver",
        "SolNode177": "Kappa",
        "SolNode178": "Hyosube",
        "SolNode179": "Jengu",
        "SolNode180": "Undine",
        "SolNode181": "Adaro",
        "SolNode182": "Camenae",
        "SolNode183": "Vodyanoi",
        "SolNode184": "Rusalka",
        "SolNode185": "Berehynia",
        "SolNode186": "Phithale",
        "SolNode187": "Selkie",
        "SolNode188": "Kelpie",
        "SolNode189": "Naga",
        "SolNode190": "Nakki",
        "SolNode191": "Marid",
        "SolNode192": "Tikoloshe",
        "SolNode193": "Merrow",
        "SolNode194": "Ponaturi",
        "SolNode195": "Hydron",
        "SolNode196": "Charybdis",
        "SolNode197": "Graeae",
        "SolNode198": "Scylla",
        "SolNode199": "Yam",
        "SolNode200": "Veles",
        "SolNode201": "Tiamat",
        "SolNode202": "Yemaja",
        "SolNode203": "Abaddon",
        "SolNode204": "Armaros",
        "SolNode205": "Baal",
        "SolNode206": "Eligor",
        "SolNode207": "Gamygyn",
        "SolNode208": "Lillith",
        "SolNode209": "Morax",
        "SolNode210": "Naamah",
        "SolNode211": "Ose",
        "SolNode212": "Paimon",
        "SolNode213": "Shax",
        "SolNode214": "Sorath",
        "SolNode215": "Valac",
        "SolNode216": "Valefor",
        "SolNode217": "Orias",
        "SolNode218": "Zagan",
        "SolNode219": "Beleth",
        "SolNode220": "Kokabiel",
        "SolNode221": "Neruda",
        "SolNode222": "Eminescu",
        "SolNode223": "Boethius",
        "SolNode224": "Odin",
        "SolNode225": "Suisei",
        "SolNode226": "Pantheon",
        "SolNode227": "Verdi",
        "SolNode228": "Plains of Eidolon",
        "SolNode400": "Teshub",
        "SolNode401": "Hepit",
        "SolNode402": "Taranis",
        "SolNode403": "Tiwaz",
        "SolNode404": "Stribog",
        "SolNode405": "Ani",
        "SolNode406": "Ukko",
        "SolNode407": "Oxomoco",
        "SolNode408": "Belenus",
        "SolNode409": "Mot",
        "SolNode410": "Aten",
        "SolNode411": "SolNode411",
        "SolNode412": "Mithra",
        "SolNode413": "SolNode413",
        "SolNode707": "Hyf",
        "SolNode711": "Terrorren",
        "SolNode712": "Magnacidium",
        "SolNode740": "The Ropalolyst",
        "SolNode741": "Koro",
        "SolNode742": "Nabuk",
        "SolNode743": "Rotuma",
        "SolNode744": "Taveuni",
        "SolNode745": "Tamu",
        "SolNode746": "Dakata",
        "SolNode747": "Pago",
        "SolNode748": "Garus",
        "SolNode901": "Caduceus",
        "SolNode902": "Montes",
        "SolNode903": "Erpo",
        "SolNode904": "Syrtis",
        "SolNode905": "Galilea",
        "SolNode906": "Pandora",
        "SolNode907": "Caelus",
        "SolNode908": "Salacia",
        "SolNode300": "Plato",
        "SolNode301": "Grimaldi",
        "SolNode302": "Tycho",
        "SolNode304": "Copernicus",
        "SolNode305": "St\u00c3\u00b6fler",
        "SolNode306": "Pavlov",
        "SolNode307": "Zeipel",
        "SolNode308": "Apollo",
        "SettlementNode1": "Roche",
        "SettlementNode2": "Skyresh",
        "SettlementNode3": "Stickney",
        "SettlementNode4": "Drunlo",
        "SettlementNode5": "Grildrig",
        "SettlementNode6": "Limtoc",
        "SettlementNode7": "Hall",
        "SettlementNode8": "Reldresal",
        "SettlementNode9": "Clustril",
        "SettlementNode10": "Kepler",
        "SettlementNode11": "Gulliver",
        "SettlementNode12": "Monolith",
        "SettlementNode13": "D'Arrest",
        "SettlementNode14": "Shklovsky",
        "SettlementNode15": "Sharpless",
        "SettlementNode16": "Wendell",
        "SettlementNode17": "Flimnap",
        "SettlementNode18": "Opik",
        "SettlementNode19": "Todd",
        "SettlementNode20": "Iliad",
        "MercuryHUB": "Larunda Relay",
        "VenusHUB": "Vesper Relay",
        "EarthHUB": "Strata Relay",
        "SaturnHUB": "Kronia Relay",
        "ErisHUB": "Kuiper Relay",
        "EuropaHUB": "Leonov Relay",
        "PlutoHUB": "Orcus Relay",
        "EventNode0": "Balor",
        "EventNode1": "Tethra",
        "EventNode2": "Operation Gate Crash",
        "EventNode3": "Elatha",
        "EventNode4": "Proxy Rebellion",
        "EventNode5": "Birog",
        "EventNode6": "Tyl Reygor Seal Lab",
        "EventNode7": "Proxy Rebellion",
        "EventNode8": "Corb",
        "EventNode9": "Operation Gate Crash Pt. 2",
        "EventNode10": "Lugh",
        "EventNode11": "Nemed",
        "EventNode12": "Operation Cryotic Front",
        "EventNode13": "Shifting Sands",
        "EventNode14": "Gate Crash",
        "EventNode15": "Operation Cryotic Front",
        "EventNode16": "Operation Cryotic Front",
        "EventNode17": "Proxy Rebellion",
        "EventNode18": "Proxy Rebellion",
        "EventNode19": "Mars",
        "EventNode20": "Tyl Regor Sea Lab",
        "EventNode22": "Tyl Regor Sea Lab",
        "EventNode24": "Earth",
        "EventNode25": "Earth",
        "EventNode26": "Earth",
        "EventNode27": "Void",
        "EventNode28": "Saturn",
        "EventNode29": "Saturn",
        "EventNode30": "Ganymede",
        "EventNode31": "Ganymede",
        "EventNode32": "Ganymede",
        "EventNode33": "Ganymede",
        "EventNode34": "Earth",
        "EventNode35": "Earth",
        "EventNode761": "The Index",
        "EventNode762": "The Index pt 2",
        "EventNode763": "The Index Endurance",
        "PvpNode0": "Conclave Capture the Cephalon",
        "PvpNode1": "Conclave",
        "PvpNode2": "Conclave",
        "PvpNode3": "Conclave Capture the Cephalon",
        "PvpNode4": "Conclave",
        "PvpNode5": "Conclave",
        "PvpNode6": "Conclave",
        "PvpNode7": "Conclave",
        "PvpNode8": "Conclave",
        "PvpNode9": "Conclave Team Domination",
        "PvpNode10": "Conclave Domination",
        "PvpNode11": "Conclave Domination",
        "PvpNode12": "Conclave Domination",
        "PvpNode13": "Tactical Alert: Snoball Fight!",
        "PvpNode14": "Conclave: Quick Steel",
        "ClanNode0": "Romula",
        "ClanNode1": "Malva",
        "ClanNode2": "Coba",
        "ClanNode3": "Tikal",
        "ClanNode4": "Sinai",
        "ClanNode5": "Cameria",
        "ClanNode6": "Larzac",
        "ClanNode7": "Cholistan",
        "ClanNode8": "Kadesh",
        "ClanNode9": "Wahiba",
        "ClanNode10": "Memphis",
        "ClanNode11": "Zeugma",
        "ClanNode12": "Caracol",
        "ClanNode13": "Piscinas",
        "ClanNode14": "Amarna",
        "ClanNode15": "Sangeru",
        "ClanNode16": "Ur",
        "ClanNode17": "Assur",
        "ClanNode18": "Akkad",
        "ClanNode19": "Zabala",
        "ClanNode20": "Yursa",
        "ClanNode21": "Kelashin",
        "ClanNode22": "Seimeni",
        "ClanNode23": "Gabii",
        "ClanNode24": "Sechura",
        "ClanNode25": "Hieracon",
        "/Lotus/Types/Keys/SortieBossKeyPhorid": "Sortie Boss: Phorid",
        "CrewBattleNode505": "Ruse War Field",
        "CrewBattleNode510": "Gian Point",
        "CrewBattleNode550": "Nsu Grid",
        "CrewBattleNode551": "Ganalen's Grave",
        "CrewBattleNode552": "Rya",
        "CrewBattleNode553": "Flexa",
        "CrewBattleNode554": "H-2 Cloud",
        "CrewBattleNode555": "R-9 Cloud"
    },
    "planet": {
        "SolNode0": "SolNode0",
        "SolNode1": "Neptune",
        "SolNode2": "Venus",
        "SolNode3": "Uranus",
        "SolNode4": "Pluto",
        "SolNode5": "Uranus",
        "SolNode6": "Neptune",
        "SolNode7": "Saturn",
        "SolNode8": "Pluto",
        "SolNode9": "Uranus",
        "SolNode10": "Jupiter",
        "SolNode11": "Mars",
        "SolNode12": "Mercury",
        "SolNode13": "Uranus",
        "SolNode14": "Mars",
        "SolNode15": "Earth",
        "SolNode16": "Mars",
        "SolNode17": "Neptune",
        "SolNode18": "Saturn",
        "SolNode19": "Saturn",
        "SolNode20": "Saturn",
        "SolNode21": "Pluto",
        "SolNode22": "Venus",
        "SolNode23": "Venus",
        "SolNode24": "Earth",
        "SolNode25": "Jupiter",
        "SolNode26": "Earth",
        "SolNode27": "Earth",
        "SolNode28": "Mercury",
        "SolNode29": "Uranus",
        "SolNode30": "Mars",
        "SolNode31": "Saturn",
        "SolNode32": "Saturn",
        "SolNode33": "Uranus",
        "SolNode34": "Uranus",
        "SolNode35": "Mars",
        "SolNode36": "Mars",
        "SolNode37": "Saturn",
        "SolNode38": "Pluto",
        "SolNode39": "Earth",
        "SolNode40": "Uranus",
        "SolNode41": "Mars",
        "SolNode42": "Saturn",
        "SolNode43": "Pluto",
        "SolNode44": "Saturn",
        "SolNode45": "Mars",
        "SolNode46": "Mars",
        "SolNode47": "Saturn",
        "SolNode48": "Pluto",
        "SolNode49": "Neptune",
        "SolNode50": "Saturn",
        "SolNode51": "Pluto",
        "SolNode52": "Uranus",
        "SolNode53": "Jupiter",
        "SolNode54": "Mars",
        "SolNode55": "Saturn",
        "SolNode56": "Pluto",
        "SolNode57": "Neptune",
        "SolNode58": "Mars",
        "SolNode59": "Earth",
        "SolNode60": "Uranus",
        "SolNode61": "Venus",
        "SolNode62": "Neptune",
        "SolNode63": "Earth",
        "SolNode64": "Uranus",
        "SolNode65": "Mars",
        "SolNode66": "Venus",
        "SolNode67": "Saturn",
        "SolNode68": "Mars",
        "SolNode69": "Uranus",
        "SolNode70": "Saturn",
        "SolNode71": "Venus",
        "SolNode72": "Pluto",
        "SolNode73": "Jupiter",
        "SolNode74": "Jupiter",
        "SolNode75": "Earth",
        "SolNode76": "Pluto",
        "SolNode77": "Uranus",
        "SolNode78": "Neptune",
        "SolNode79": "Earth",
        "SolNode80": "Saturn",
        "SolNode81": "Pluto",
        "SolNode82": "Saturn",
        "SolNode83": "Uranus",
        "SolNode84": "Neptune",
        "SolNode85": "Earth",
        "SolNode86": "Saturn",
        "SolNode87": "Jupiter",
        "SolNode88": "Jupiter",
        "SolNode89": "Earth",
        "SolNode90": "Miranda",
        "SolNode91": "Saturn",
        "SolNode92": "Pluto",
        "SolNode93": "Saturn",
        "SolNode94": "Mercury",
        "SolNode95": "Neptune",
        "SolNode96": "Saturn",
        "SolNode97": "Jupiter",
        "SolNode98": "Uranus",
        "SolNode99": "Mars",
        "SolNode100": "Jupiter",
        "SolNode101": "Venus",
        "SolNode102": "Pluto",
        "SolNode103": "Mercury",
        "SolNode104": "Venus",
        "SolNode105": "Uranus",
        "SolNode106": "Mars",
        "SolNode107": "Venus",
        "SolNode108": "Mercury",
        "SolNode109": "Venus",
        "SolNode110": "Saturn",
        "SolNode111": "Uranus",
        "SolNode112": "Uranus",
        "SolNode113": "Mars",
        "SolNode114": "Uranus",
        "SolNode115": "Mars",
        "SolNode116": "Uranus",
        "SolNode117": "Neptune",
        "SolNode118": "Neptune",
        "SolNode119": "Mercury",
        "SolNode120": "Neptune",
        "SolNode121": "Jupiter",
        "SolNode122": "Uranus",
        "SolNode123": "Venus",
        "SolNode124": "Uranus",
        "SolNode125": "Jupiter",
        "SolNode126": "Jupiter",
        "SolNode127": "Neptune",
        "SolNode128": "Venus",
        "SolNode129": "Venus",
        "SolNode130": "Mercury",
        "SolNode131": "Ceres",
        "SolNode132": "Ceres",
        "SolNode133": "Ceres",
        "SolNode134": "Ceres",
        "SolNode135": "Ceres",
        "SolNode136": "Ceres",
        "SolNode137": "Ceres",
        "SolNode138": "Ceres",
        "SolNode139": "Ceres",
        "SolNode140": "Ceres",
        "SolNode141": "Ceres",
        "SolNode142": "Ceres",
        "SolNode143": "Ceres",
        "SolNode144": "Ceres",
        "SolNode145": "Ceres",
        "SolNode146": "Ceres",
        "SolNode147": "Ceres",
        "SolNode148": "Ceres",
        "SolNode149": "Ceres",
        "SolNode150": "Ceres",
        "SolNode151": "Eris",
        "SolNode152": "Eris",
        "SolNode153": "Eris",
        "SolNode154": "Eris",
        "SolNode155": "Eris",
        "SolNode156": "Eris",
        "SolNode157": "Eris",
        "SolNode158": "Eris",
        "SolNode159": "Eris",
        "SolNode160": "Eris",
        "SolNode161": "Eris",
        "SolNode162": "Eris",
        "SolNode163": "Eris",
        "SolNode164": "Eris",
        "SolNode165": "Eris",
        "SolNode166": "Eris",
        "SolNode167": "Eris",
        "SolNode168": "Eris",
        "SolNode169": "Eris",
        "SolNode170": "Eris",
        "SolNode171": "Eris",
        "SolNode172": "Eris",
        "SolNode173": "Eris",
        "SolNode174": "Eris",
        "SolNode175": "Eris",
        "SolNode176": "Eris",
        "SolNode177": "Sedna",
        "SolNode178": "Sedna",
        "SolNode179": "Sedna",
        "SolNode180": "Sedna",
        "SolNode181": "Sedna",
        "SolNode182": "Sedna",
        "SolNode183": "Sedna",
        "SolNode184": "Sedna",
        "SolNode185": "Sedna",
        "SolNode186": "Sedna",
        "SolNode187": "Sedna",
        "SolNode188": "Sedna",
        "SolNode189": "Sedna",
        "SolNode190": "Sedna",
        "SolNode191": "Sedna",
        "SolNode192": "Sedna",
        "SolNode193": "Sedna",
        "SolNode194": "Sedna",
        "SolNode195": "Sedna",
        "SolNode196": "Sedna",
        "SolNode197": "Sedna",
        "SolNode198": "Sedna",
        "SolNode199": "Sedna",
        "SolNode200": "Sedna",
        "SolNode201": "Sedna",
        "SolNode202": "Sedna",
        "SolNode203": "Europa",
        "SolNode204": "Europa",
        "SolNode205": "Europa",
        "SolNode206": "Europa",
        "SolNode207": "Europa",
        "SolNode208": "Europa",
        "SolNode209": "Europa",
        "SolNode210": "Europa",
        "SolNode211": "Europa",
        "SolNode212": "Europa",
        "SolNode213": "Europa",
        "SolNode214": "Europa",
        "SolNode215": "Europa",
        "SolNode216": "Europa",
        "SolNode217": "Europa",
        "SolNode218": "Europa",
        "SolNode219": "Europa",
        "SolNode220": "Europa",
        "SolNode221": "Mercury",
        "SolNode222": "Mercury",
        "SolNode223": "Mercury",
        "SolNode224": "Mercury",
        "SolNode225": "Mercury",
        "SolNode226": "Mercury",
        "SolNode227": "Mercury",
        "SolNode228": "Earth",
        "SolNode400": "Void",
        "SolNode401": "Void",
        "SolNode402": "Void",
        "SolNode403": "Void",
        "SolNode404": "Void",
        "SolNode405": "Void",
        "SolNode406": "Void",
        "SolNode407": "Void",
        "SolNode408": "Void",
        "SolNode409": "Void",
        "SolNode410": "Void",
        "SolNode411": "Void",
        "SolNode412": "Void",
        "SolNode413": "Void",
        "SolNode707": "Deimos",
        "SolNode711": "Deimos",
        "SolNode712": "Deimos",
        "SolNode740": "Jupiter",
        "SolNode741": "Kuva Fortress",
        "SolNode742": "Kuva Fortress",
        "SolNode743": "Kuva Fortress",
        "SolNode744": "Kuva Fortress",
        "SolNode745": "Kuva Fortress",
        "SolNode746": "Kuva Fortress",
        "SolNode747": "Kuva Fortress",
        "SolNode748": "Kuva Fortress",
        "SolNode901": "Caduceus",
        "SolNode902": "Venus",
        "SolNode903": "Earth",
        "SolNode904": "Mars",
        "SolNode905": "Jupiter",
        "SolNode906": "Saturn",
        "SolNode907": "Uranus",
        "SolNode908": "Neptune",
        "SolNode300": "Lua",
        "SolNode301": "Lua",
        "SolNode302": "Lua",
        "SolNode304": "Lua",
        "SolNode305": "Lua",
        "SolNode306": "Lua",
        "SolNode307": "Lua",
        "SolNode308": "Lua",
        "SettlementNode1": "Phobos",
        "SettlementNode2": "Phobos",
        "SettlementNode3": "Phobos",
        "SettlementNode4": "Phobos",
        "SettlementNode5": "Phobos",
        "SettlementNode6": "Phobos",
        "SettlementNode7": "Phobos",
        "SettlementNode8": "Phobos",
        "SettlementNode9": "Phobos",
        "SettlementNode10": "Phobos",
        "SettlementNode11": "Phobos",
        "SettlementNode12": "Phobos",
        "SettlementNode13": "Phobos",
        "SettlementNode14": "Phobos",
        "SettlementNode15": "Phobos",
        "SettlementNode16": "Phobos",
        "SettlementNode17": "Phobos",
        "SettlementNode18": "Phobos",
        "SettlementNode19": "Phobos",
        "SettlementNode20": "Phobos",
        "MercuryHUB": "Mercury",
        "VenusHUB": "Venus",
        "EarthHUB": "Earth",
        "SaturnHUB": "Saturn",
        "ErisHUB": "Eris",
        "EuropaHUB": "Europa",
        "PlutoHUB": "Pluto",
        "EventNode0": "Balor",
        "EventNode1": "Tethra",
        "EventNode2": "Operation Gate Crash",
        "EventNode3": "Elatha",
        "EventNode4": "Proxy Rebellion",
        "EventNode5": "Birog",
        "EventNode6": "Tyl Reygor Seal Lab",
        "EventNode7": "Proxy Rebellion",
        "EventNode8": "Corb",
        "EventNode9": "Operation Gate Crash Pt. 2",
        "EventNode10": "Lugh",
        "EventNode11": "Nemed",
        "EventNode12": "Operation Cryotic Front",
        "EventNode13": "Shifting Sands",
        "EventNode14": "Gate Crash",
        "EventNode15": "Operation Cryotic Front",
        "EventNode16": "Operation Cryotic Front",
        "EventNode17": "Proxy Rebellion",
        "EventNode18": "Proxy Rebellion",
        "EventNode19": "Mars",
        "EventNode20": "Tyl Regor Sea Lab",
        "EventNode22": "Tyl Regor Sea Lab",
        "EventNode24": "Earth",
        "EventNode25": "Earth",
        "EventNode26": "Earth",
        "EventNode27": "Void",
        "EventNode28": "Saturn",
        "EventNode29": "Saturn",
        "EventNode30": "Jupiter",
        "EventNode31": "Jupiter",
        "EventNode32": "Jupiter",
        "EventNode33": "Jupiter",
        "EventNode34": "Earth",
        "EventNode35": "Earth",
        "EventNode761": "The Index",
        "EventNode762": "The Index pt 2",
        "EventNode763": "The Index Endurance",
        "PvpNode0": "Conclave Capture the Cephalon",
        "PvpNode1": "Conclave",
        "PvpNode2": "Conclave",
        "PvpNode3": "Conclave Capture the Cephalon",
        "PvpNode4": "Conclave",
        "PvpNode5": "Conclave",
        "PvpNode6": "Conclave",
        "PvpNode7": "Conclave",
        "PvpNode8": "Conclave",
        "PvpNode9": "Conclave Team Domination",
        "PvpNode10": "Conclave Domination",
        "PvpNode11": "Conclave Domination",
        "PvpNode12": "Conclave Domination",
        "PvpNode13": "Tactical Alert: Snoball Fight!",
        "PvpNode14": "Conclave: Quick Steel",
        "ClanNode0": "Venus",
        "ClanNode1": "Venus",
        "ClanNode2": "Earth",
        "ClanNode3": "Earth",
        "ClanNode4": "Jupiter",
        "ClanNode5": "Jupiter",
        "ClanNode6": "Europa",
        "ClanNode7": "Europa",
        "ClanNode8": "Mars",
        "ClanNode9": "Mars",
        "ClanNode10": "Phobos",
        "ClanNode11": "Phobos",
        "ClanNode12": "Saturn",
        "ClanNode13": "Saturn",
        "ClanNode14": "Sedna",
        "ClanNode15": "Sedna",
        "ClanNode16": "Uranus",
        "ClanNode17": "Uranus",
        "ClanNode18": "Eris",
        "ClanNode19": "Eris",
        "ClanNode20": "Neptune",
        "ClanNode21": "Neptune",
        "ClanNode22": "Ceres",
        "ClanNode23": "Ceres",
        "ClanNode24": "Pluto",
        "ClanNode25": "Pluto",
        "/Lotus/Types/Keys/SortieBossKeyPhorid": "Sortie Boss: Phorid",
        "CrewBattleNode505": "Veil Proxima",
        "CrewBattleNode510": "Veil Proxima",
        "CrewBattleNode550": "Veil Proxima",
        "CrewBattleNode551": "Veil Proxima",
        "CrewBattleNode552": "Veil Proxima",
        "CrewBattleNode553": "Veil Proxima",
        "CrewBattleNode554": "Veil Proxima",
        "CrewBattleNode555": "Veil Proxima"
    },
    "era": {
        "VoidT1": "Lith",
        "VoidT2": "Meso",
        "VoidT3": "Neo",
        "VoidT4": "Axi",
        "VoidT5": "Requiem"
    },
    "missions": {
        "MT_CAPTURE": "Capture",
        "MT_DEFENSE": "Defense",
        "MT_EXCAVATE": "Excavation",
        "MT_EXTERMINATION": "Exterminate",
        "MT_HIVE": "Hive",
        "MT_INTEL": "Spy",
        "MT_MOBILE_DEFENSE": "Mobile Defense",
        "MT_RESCUE": "Rescue",
        "MT_SABOTAGE": {
            "SolNode10": "Gas City Sabotage",
            "SolNode19": "Machine Sabotage",
            "SolNode56": "Ship Sabotage",
            "SolNode57": "Core Sabotage",
            "SolNode61": "Ship Sabotage",
            "SolNode75": "Injector Sabotage",
            "SolNode82": "Ship Sabotage",
            "SolNode88": "Ship Sabotage",
            "SolNode113": "Core Sabotage",
            "SolNode135": "Ship Sabotage",
            "SolNode141": "Core Sabotage",
            "SolNode184": "Ship Sabotage",
            "SolNode220": "Core Sabotage",
            "SolNode404": "Orokin Sabotage"
        },
        "MT_SURVIVAL": "Survival",
        "MT_TERRITORY": "Interception",
        "MT_ARTIFACT": "Disruption",
        "MT_ASSAULT": "Assault"
    },
    "tier": {
        "MT_CAPTURE": 1,
        "MT_DEFENSE": 5,
        "MT_EXCAVATE": 4,
        "MT_EXTERMINATION": 1,
        "MT_HIVE": 3,
        "MT_INTEL": 3,
        "MT_MOBILE_DEFENSE": 5,
        "MT_RESCUE": 2,
        "MT_SABOTAGE": {
            "SolNode10": 3,
            "SolNode19": 2,
            "SolNode56": 2,
            "SolNode57": 2,
            "SolNode61": 2,
            "SolNode75": 3,
            "SolNode82": 2,
            "SolNode88": 2,
            "SolNode113": 2,
            "SolNode135": 2,
            "SolNode141": 2,
            "SolNode184": 2,
            "SolNode220": 2,
            "SolNode404": 3
        },
        "MT_SURVIVAL": 5,
        "MT_TERRITORY": 5,
        "MT_ARTIFACT": 4,
        "MT_ASSAULT": 5
    }
}


def build_fissure_list():
    fissures = {'fissures':
                    {'Lith': [],
                     'Meso': [],
                     'Neo': [],
                     'Axi': [],
                     'Requiem': []},
                'resets':
                    {'Lith': [],
                     'Meso': [],
                     'Neo': [],
                     'Axi': [],
                     'Requiem': []}
                }
    fissures_raw = json.load(urlopen("http://content.warframe.com/dynamic/worldState.php"))["ActiveMissions"]

    for fissure in fissures_raw:
        expiry = int(fissure['Expiry']['$date']['$numberLong']) // 1000
        if time.time() > expiry:
            continue
        era = parse_fissure('era', fissure['Modifier'])
        fissures['resets'][era].append(expiry)

        fissures['fissures'][era].append(
            {"Mission": parse_fissure('missions', fissure['MissionType'], fissure['Node']),
             "Location": parse_fissure('location', fissure['Node']),
             "Planet": parse_fissure('planet', fissure['Node']),
             "Expiry": expiry,
             "Tier": parse_fissure("tier", fissure['MissionType'], fissure['Node'])})

    for era in fissures['resets']:
        fissures['resets'][era] = max(fissures['resets'][era]) - 180

    return fissures
